﻿#define LOG

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Arction.LightningChartUltimate;
using Arction.LightningChartUltimate.Axes;
using Arction.LightningChartUltimate.SeriesXY;

namespace AL_FontSize
{
    public partial class Form1 : Form
    {
        #region Membervariables

        private LightningChartUltimate lightning;
        private IntensityGridSeries series;
        private AxisX axisX;
        private AxisY axisY;

        int _cols = 10;
        int _rows = 10;
        double[][] _data;

        private readonly Random _random = new Random();

        #endregion

        #region Constructor

        public Form1()
        {
            InitializeComponent();

            InitChart();
        }

        #endregion

        private void trackBar1_Scroll(object sender, EventArgs e)
        {
            UpdateFontsize(trackBar1.Value);
        }

        #region InitChart() ++

        void InitChart()
        {
            lightning = new LightningChartUltimate()
            {
                Dock = DockStyle.Fill,
                ActiveView = ActiveView.ViewXY,
            };
            lightning.Title.Visible = false;

            var view = lightning.ViewXY;

            lightning.BeginUpdate();

            view.LegendBox.Visible = false;

            view.AxisLayout.AutoAdjustMargins = true;
            view.AxisLayout.XAxisTitleAutoPlacement = true;
            view.AxisLayout.YAxisTitleAutoPlacement = true;
            view.AxisLayout.AutoAdjustMargins = true;

            view.XAxes.Clear();
            view.YAxes.Clear();

            axisX = createXAxis();
            axisY = createYAxis();

            series = new IntensityGridSeries(lightning.ViewXY, axisX, axisY)
            {
                PixelRendering = false,
                MouseInteraction = false,
            };
            series.ValueRangePalette = CreatePalette(series, 0, 58);

            lightning.ViewXY.IntensityGridSeries.Add(series);

            #region CreateData

            const double k = 10;
            series.SetRangesXY(-k, k, -k, k);
            series.SetSize(_cols, _rows);

            _data = new double[_cols][];
            for (int x = 0; x < _cols; x++)
            {
                var colData = new double[_rows];
                for (int y = 0; y < _rows; y++)
                    colData[y] = 4 * x + y + 8.0 * _random.NextDouble();
                _data[x] = colData;
            }

            series.SetValuesData(_data, IntensityGridValuesDataOrder.ColumnsRows);
            series.InvalidateValuesDataOnly();

            #endregion

            axisX.SetRange(-k, k);
            axisY.SetRange(-k, k);

            lightning.EndUpdate();
            this.Controls.Add(lightning);
            lightning.BringToFront();
        }

        AxisX createXAxis()
        {
            var axis = new AxisX(lightning.ViewXY);
            axis.MouseInteraction = true;
            axis.LabelTicksGap = 1;
            axis.MajorGrid.Visible = true;
            axis.MinorGrid.Visible = false;
            axis.MajorDivTickStyle.Alignment = Alignment.Far;
            axis.MajorDivTickStyle.LineLength = 7;
            axis.MinorDivTickStyle.Alignment = Alignment.Far;
            axis.MinorDivTickStyle.LineLength = 3;
            axis.Title.MouseInteraction = false;
            axis.Title.Text = "AxisLabel";
            axis.Title.DistanceToAxis = 7 + 20;
            axis.Units.Visible = false;
            axis.ValueType = AxisValueType.Number;

            axis.KeepDivCountOnRangeChange = false;

            lightning.ViewXY.XAxes.Add(axis);

            return axis;
        }

        AxisY createYAxis()
        {
            var axis = new AxisY(lightning.ViewXY);
            axis.MouseInteraction = true;
            axis.LabelTicksGap = 1;
            axis.MajorGrid.Visible = true;
            axis.MinorGrid.Visible = false;
            axis.MajorDivTickStyle.Alignment = Alignment.Near;
            axis.MajorDivTickStyle.LineLength = 7;
            axis.MinorDivTickStyle.Alignment = Alignment.Near;
            axis.MinorDivTickStyle.LineLength = 3;
            axis.Title.MouseInteraction = false;
            axis.Title.Text = "AxisLabel";
            axis.Units.Visible = false;

            axis.KeepDivCountOnRangeChange = false;

            axis.ValueType = AxisValueType.Number;

#if LOG
            axis.ScaleType = ScaleType.Logarithmic;
#else
            axis.ScaleType = ScaleType.Linear;
#endif
            axis.LogBase = 10;
            axis.LogLabelsType = LogLabelsType.Regular;
            axis.LogZeroClamp = 10E-9;
            axis.AutoFormatLabels = true;
            axis.LabelsNumberFormat = "g";

            lightning.ViewXY.YAxes.Add(axis);

            return axis;
        }

        #region Palette

        void SetPalette(double colMin, double colMax)
        {
            lightning.BeginUpdate();

            series.ValueRangePalette = CreatePalette(series, colMin, colMax);

            lightning.EndUpdate();
        }

        public static readonly Color[] listRainbox = new Color[] { Color.Purple, Color.Blue, Color.Green, Color.Yellow, Color.Red };

        private ValueRangePalette CreatePalette(IntensityGridSeries ownerSeries, double min, double max)
        {
            var palette = new ValueRangePalette(ownerSeries)
            {
                Type = PaletteType.Gradient,
            };

            Color[] colorList = listRainbox;

            int colorCount = colorList.Length;
            var step = (max - min) / (colorCount - 1);

            palette.Steps.Clear();

            double pos = min;
            for (int i = 0; i < colorCount; i++)
            {
                palette.Steps.Add(new PaletteStep(palette, colorList[i], pos));
                pos += step;
            }

            return palette;
        }

        #endregion


        #endregion

        void UpdateFontsize(int fontSize)
        {
            var diagramFont = new Font(FontFamily.GenericSansSerif, fontSize, FontStyle.Regular);

            lightning.BeginUpdate();

            lightning.Font = diagramFont;
            axisX.LabelsFont = diagramFont;
            axisX.Title.Font = diagramFont;
            axisY.LabelsFont = diagramFont;
            axisY.Title.Font = diagramFont;

            lightning.EndUpdate();
        }
    }
}
